#ifndef __CTDLAYER__
#define __CTDLAYER__
//*************************************************************************
//* ===============
//*  CTDLayer Class
//* ===============
//*
//* (Description)
//*    Charged track detector layer class.
//* (Requires)
//* (Provides)
//* 	class CTDlayer
//* (Update Recored)
//*    1999/11/08  K.Fujii	Original version.
//*
//*************************************************************************
//
#include <iostream.h>
#include <iomanip.h>
#include "TMatrix.h"
//_____________________________________________________________________
//  --------
//  CTDLayer
//  --------
//
class CTDLayer : public TObject {
friend class CTDTracker;
public:
   CTDLayer(Char_t *s="Air", Int_t n=0, Double_t r=0., Double_t t=0.,
   	    Double_t b=3., Double_t x0=3.5e-5, Double_t sg=1.);
   CTDLayer(CTDLayer &l, Double_t r);
   CTDLayer(const CTDLayer &l);
   virtual ~CTDLayer() {}

   inline void SetName     (Char_t *s)  { fName      = s; }
   inline void SetNsample  (Int_t n)    { fNsample   = n; }
   inline void SetThickness(Double_t x) { fThickness = x; }
   inline void SetSigmaX   (Double_t x) { fSigmaX    = x; }
   inline void SetX0       (Double_t x) { fX0        = x; }
   inline void SetBField   (Double_t x) { fB         = x; }
   inline void SetR(Double_t rin) {
      fRin = rin;
      fRout = rin + fThickness;
   }

   inline Char_t  *GetLayerName() const { return fName;      }
   inline Int_t    GetNsample()   const { return fNsample;   }
   inline Double_t GetThickness() const { return fThickness; }
   inline Double_t GetSigmaX()	  const { return fSigmaX;    }
   inline Double_t GetX0()	  const { return fX0;        }
   inline Double_t GetBField()	  const { return fB;         }
   inline Double_t GetRin()	  const { return fRin;       }
   inline Double_t GetRout()	  const { return fRout;      }

   inline Bool_t IsSortable() const { return kTRUE; }
   inline Int_t  Compare(TObject *obj)
   {
      CTDLayer *l = (CTDLayer *)obj;
      if (fRout <= l->fRin) return -1;
      else if (fRin >= l->fRout) return 1;
      else return 0;
   }

   void DebugPrint(const Char_t *opt = "Brief");

public:
   static const Double_t kX0Be;		//! X0_Be
   static const Double_t kX0Air;	//! X0_air
   static const Double_t kX0Si;		//! X0_Si
   static const Double_t kX0CFRP;	//! X0_CFRP
   static const Double_t kX0CDC;	//! X0_CDCgas
   static const Double_t kCms;		//! MS constant
   static const Double_t kCptor;	//! P-to-R constant

private:
   TMatrix GetEfull (Double_t p, Double_t tanl);
   TMatrix GetDelEms(Double_t p, Double_t tanl);

private:
   Char_t  *fName;	// name
   Int_t    fNsample;	// number of sampling points (0 = dead region) 
   Double_t fThickness;	// thickness of the layer (cm)
   Double_t fSigmaX;	// sigma_x (cm) if active
   Double_t fX0;	// radiation length (X0/cm)
   Double_t fB;		// magnetic field (T)
   Double_t fRin;	// R_in  of the layer (cm)
   Double_t fRout;	// R_out of the layer (cm)

   ClassDef(CTDLayer,1)  // Charged Track Detector Layer class
};

#endif
